@@ -1,5 +1,5 @@
 name = "dLux"
-__version__ = "0.9.2"
+__version__ = "0.10.0"
 
 # Import as modules
 from . import core
@@ -8,8 +8,10 @@ from . import optics
 from . import wavefronts
 from . import propagators
 from . import utils
+from . import apertures
 from . import sources
 from . import spectrums
+from . import exceptions
 
 # Import core functions from modules
 from .core        import *
@@ -17,15 +19,17 @@ from .detectors   import *
 from .optics      import *
 from .wavefronts  import *
 from .propagators import *
+from .apertures   import *
 from .sources     import *
 from .spectrums   import *
+from .exceptions  import *
 
 # Add to __all__
 __all__ = core.__all__ + detectors.__all__ + optics.__all__ + \
             wavefronts.__all__ + propagators.__all__ + sources.__all__ + \
-            spectrums.__all__
+            spectrums.__all__ + apertures.__all__ 
 
 # Check for 64-bit
 from jax import config
 if not config.x64_enabled:
-    print("dLux warning: Jax is running in 32-bit, to enable 64-bit visit:\nhttps://jax.readthedocs.io/en/latest/notebooks/Common_Gotchas_in_JAX.html#double-64bit-precision")
\ No newline at end of file
+    print("dLux: Jax is running in 32-bit, to enable 64-bit visit:\nhttps://jax.readthedocs.io/en/latest/notebooks/Common_Gotchas_in_JAX.html#double-64bit-precision")
