@@ -4,6 +4,7 @@ from jax import vmap
 from jax.tree_util import tree_map, tree_flatten
 from jax.scipy.ndimage import map_coordinates
 from equinox import tree_at, static_field
+from zodiax import ExtendedBase
 from collections import OrderedDict
 from copy import deepcopy
 from functools import partial
@@ -174,7 +175,7 @@ def model(optics      : Optics,
         return image.flatten() if flatten else image
 
 
-class Instrument(dLux.base.ExtendedBase):
+class Instrument(ExtendedBase):
     """
     A high level class desgined to model the behaviour of a telescope. It
     stores a series different ∂Lux objects, and primarily passes the relevant
@@ -410,14 +411,13 @@ class Instrument(dLux.base.ExtendedBase):
         item : object
             The item corresponding to the supplied key in the sub-dictionaries.
         """
-
-        if self.optics is not None and hasattr(self.optics, 'layers') and \
+        if 'optics' in vars(self) and hasattr(self.optics, 'layers') and \
                                         key in self.optics.layers.keys():
             return self.optics.layers[key]
-        elif self.detector is not None and hasattr(self.detector, 'layers') and\
+        elif 'detector' in vars(self) and hasattr(self.detector, 'layers') and \
                                         key in self.detector.layers.keys():
             return self.detector.layers[key]
-        elif self.scene is not None and hasattr(self.scene, 'sources') and \
+        elif 'scene' in vars(self) and hasattr(self.scene, 'sources') and \
                                         key in self.scene.sources.keys():
             return self.scene.sources[key]
         else:
@@ -481,7 +481,11 @@ class Instrument(dLux.base.ExtendedBase):
             single array (if return_tree is false), or a pytree like object
             with matching tree strucutre as the input scene/sources/source.
         """
-        optics = optics if 'optics' in kwargs else self.optics
+        if 'optics' in kwargs:
+            optics = kwargs['optics']
+            kwargs.pop('optics')
+        else:
+            optics = self.optics
         kwargs['detector'] = self.detector if 'detector' not in kwargs \
                                                         else kwargs['detector']
         kwargs['filter']   = self.filter   if 'filter'   not in kwargs \
@@ -495,7 +499,7 @@ class Instrument(dLux.base.ExtendedBase):
                      **kwargs)
 
 
-class Optics(dLux.base.ExtendedBase):
+class Optics(ExtendedBase):
     """
     A high level class desgined to model the behaviour of some optical systems
     response to wavefronts.
@@ -546,7 +550,7 @@ class Optics(dLux.base.ExtendedBase):
         item : object
             The item corresponding to the supplied key in the layers dictionary.
         """
-        if key in self.layers.keys():
+        if 'layers' in vars(self) and key in self.layers.keys():
             return self.layers[key]
         else:
             raise AttributeError("'{}' object has no attribute '{}'"\
@@ -759,7 +763,7 @@ class Optics(dLux.base.ExtendedBase):
         return model(self, **kwargs)
 
 
-class Scene(dLux.base.ExtendedBase):
+class Scene(ExtendedBase):
     """
     A high level class representing some 'astrophysical scene', which is
     composed of dLux.sources.Sources.
@@ -810,7 +814,7 @@ class Scene(dLux.base.ExtendedBase):
             The item corresponding to the supplied key in the sources
             dictionary.
         """
-        if key in self.sources.keys():
+        if 'sources' in vars(self) and key in self.sources.keys():
             return self.sources[key]
         else:
             raise AttributeError("'{}' object has no attribute '{}'"\
@@ -875,7 +879,7 @@ class Scene(dLux.base.ExtendedBase):
         return model(optics, scene=self, **kwargs)
 
 
-class Detector(dLux.base.ExtendedBase):
+class Detector(ExtendedBase):
     """
     A high level class desgined to model the behaviour of some detectors
     response to some psf.
@@ -928,7 +932,7 @@ class Detector(dLux.base.ExtendedBase):
         item : object
             The item corresponding to the supplied key in the layers dictionary.
         """
-        if key in self.layers.keys():
+        if 'layers' in vars(self) and key in self.layers.keys():
             return self.layers[key]
         else:
             raise AttributeError("'{}' object has no attribute '{}'"\
@@ -1035,7 +1039,7 @@ class Detector(dLux.base.ExtendedBase):
         return model(optics, detector=self, **kwargs)
 
 
-class Filter(dLux.base.ExtendedBase):
+class Filter(ExtendedBase):
     """
     A class for modelling optical filters.
 
@@ -1217,7 +1221,7 @@ class Filter(dLux.base.ExtendedBase):
 
 
 """Legacy code"""
-class OpticalSystem(dLux.base.ExtendedBase):
+class OpticalSystem(ExtendedBase):
     """ Optical System class, Equinox Modle
     
     DOCSTRING NOT COMPLETE
